//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Kotsu](index.md)/[afterDiscard](after-discard.md)

# afterDiscard

[common]\
open override fun [afterDiscard](after-discard.md)(discard: [Tile](../-tile/index.md)): [Tatsu](../-tatsu/index.md)

舍牌后形成的搭子
